package drakxos;

=head1 NAME

drakxos - Quick XOS overview

=head1 SYNOPSIS

 use interactive;
 use drakxos;

 my $in = 'interactive'->vnew('');
 drakxos::create_wizard($in);

=cut


use common;

sub create_wizard {
  my ($in) = @_;
  my $new_name;
  require wizards;
  my $wiz = wizards->new({
			  defaultimage => "drakxos",
			  name => N("XtreemOS overview"),
			  pages => {
				    welcome => {
						no_back => 1,
						name => N("What's XtreemOS"),
						data => [ {
							   label => N("XtreemOS is a Linux-based operating system providing native support for virtual organizations (VOs) in next-generation grids. Unlike the traditional, middleware-based approaches, it is a prominent goal to provide seamless support for VOs, on all software layers involved, ranging from the operating system of a node, via the VO-global services, up to direct application support."),
							  } ],
						next => "rootca",
					       },
				    rootca => {
					       name => N("Installing and Configuring the XtreemOS Root Certification Authority (Root CA)"),
					       data => [ {
							  label => N("The Root CA is the top level of the trust mechanism in XtreemOS. It is a critical part in the XtreemOS Public Key Infrastructure (PKI). To achieve and maintain the level of trust required by users of an XtreemOS Grid, the Root CA must be operated only on one machine. This host must be a physically-secure core node to avoid compromise of the Root CA private key, which would destroy any trust placed on the Root CA. Some organisations may choose to run the Root CA on a machine which isn't connected to a network, to eliminate any risk of intrusion."),
							} ],
					       next => "xvoms",
					      },
				    xvoms => {
					  name => N("Configuring X-VOMS"),
					  data => [ {
						     label => N("X-VOMS (XtreemOS Virtual Organization Management Service) is an advanced Virtual Organisation (VO) management service for supporting secure and flexible collaborations and resource sharing among people, projects and organisations. It is written in Java and back by a (Hibernate-based) X-VOMS database schema. Like other VO management software packages, X-VOMS provides a set of APIs for managing identity, attributes, and VO membership of users and resources. "),
						   } ],
					  next => "cda",
					 },
				    cda => {
					  name => N("Configuring and Running Credential Distribution Authority (CDA) Server "),
					  data => [ {
						     label => N("The CDA server issues XOS certificates to users. The server needs a host certificate issued by the Root CA to authenticate itself to the corresponding CDA client. This host certificate can be obtained by the procedure described in section 5.1.7. This procedure also produces a private key, which should be placed into /etc/xos/truststore/private/cda.key. The host certificate contains the server's public key, and should be placed in /etc/xos/truststore/certs/cda.crt. "),
						   } ],
					  next => "volife",
					 },
				    volife => {
					  name => N("Installing VOLife"),
					  data => [ {
						     label => N("Virtual Organization Lifecycle Management(VOLife) is a web-based tool for accessing various VO-related services in XtreemOS. Currently VOLife only supports the manuiplation of XVOMS database and the generation of XOS-Certs for users. Integration with runtime security services such as VOPS and RCA is still under development. "),
						   } ],
					  next => "dixi",
				    },
				    dixi => {
					  name => N("Installing DIXI "),
					  data => [ {
						     label => N("DIXI (DIstributed Xtreemos Infrastructure) is a framework for running several of the VOM-related services. Before installing and using services for RCA and VOPS, it is essential to first install DIXI. DIXI is not required for CDA, X-VOMS and VOLife."),
						   } ],
					  next => "rca",
					 },
				    rca => {
					  name => N("RCA"),
					  data => [ {
						     label => N("The Resource Certification Authority services run as DIXI services. RCA comes in two packages: vom-rca-node : contains the node level service which should run on each node capable of executing jobs, vom-rca-server :contains the core-side service which usually runs on one node within a physical organisation.
"),
						   } ],
					  next => "vops",
					 },
				    vops => {
					  name => N("VOPS"),
					  data => [ {
						     label => N("VOPS is a core-level service which, due to usage of the DIXI framework, runs as a service using DIXI communication stages. Please refer to Section 5.1.5 for details. VOPS has to be started in a way like other XOS daemons are: using xosd script provided in a bundle containing VOPS package. First, administrator has to set up XOSdConfig.conf and VOPSConfig.conf appropriately. ResMng.conf (on server, where ResMng service is running) has to be configured appropriately to use VOPS, see also figure 9. VOPS is a server primarily intended serving requests and forwarding answers from/to resource discovery services and therefore it needs private key and public certificate to be able to digitally sign its decisions before forwarding them to services. Services querying VOPS should have access to VOPS public certificate to be able to check authenticity of its answers. To obtain VOPS server key/certificate please refer to section 5.1.3 where steps for obtaining server certificate is described."),
						   } ],
					  next => "aem",
					    },
				    aem => {
					     name => N("Application Execution Management "),
					     data => [ {
							label => N("The AEM services mostly host in a DIXI framework. In order to install DIXI, please refer to Section 5.1.5. In order to run one or more AEM services, the DIXI daemon's configuration file (XOSdConfig.conf by default, please refer to Section 5.1.5 for more details) needs to have its handler enabled."),
						       } ],
					     next => "rss",
					    },
				    rss => {
					     name => N("Resource Selection Service"),
					     data => [ {
							label => N("The RSS (Resource selection service) is a Java service that provides an overlay network (exploiting the Cyclon communication layer) to efficiently locate computing resources based on their static attributes.\n
RSS interacts with SRDS, the two modules run inside the same JVM and have one instance per computing resource. Beside that, The RSS network needs one additional process to manage nodes who want to join the RSS overlay. This process (called Recorder) has to be active exactly on one node and to be known to all the others."),
						       } ],
					     next => "srds",
					    },
				    srds => {
					     name => N("Scalable Resource Discovery System"),
					     data => [ {
							label => N("The SRDS (Scalable Resource Discovery Service) provides several types of directory services to other modules of XtreemOS. Different interfaces and set of functionalities are defined for each client. This first release provides to the AEM module the Resource Location Service and the Job Directory Service. They respectively return a list of computing resources matching a specific resoruce query (JSDL), and allow to manage job information in a decentralized manner."),
						       } ],
					     next => "xosfs",
					    },
				    xosfs => {
					     name => N("XtreemFS"),
					     data => [ {
							label => N("XtreemFS is the distributed file system of XtreemOS. It comprises three server modules: Metadata and Replica Catalog (MRC), Object Storage Device (OSD), Directory Service (DIR)"),
						       } ],
					     next => "ssi",
					    },
				    ssi => {
					     name => N("LinuxSSI"),
					     data => [ {
							label => N("A LinuxSSI cluster can act as a resource in XtreemOS. Please, do not use it as a server node. Beware that all your cluster nodes must be on the same physical network. There must be no router between them. "),
						       } ],
					     next => "end",
					    },

				    end => {
					    name => N("XtreemOS documentation is available at: http://www.xtreemos.eu"),
					    end => 1,
					    no_back => 1,
					   },
				   },
			 });
  $wiz->process($in);
}

1;
