package xtreemos;



use run_program;
use detect_devices;
use network::network;
use common;
use services;
use xtreemos::xtreemfs_osd;
use xtreemos::xtreemfs_mrc;
use xtreemos::xtreemfs_dir;
use xtreemos::xosd;
use xtreemos::xvoms;
use xtreemos::rss;
use xtreemos::srds;
use xtreemos::xtreemos_check;
use run_program;
use mygtk2 qw(gtknew);
use ugtk2 qw(:wrappers :create :ask);
use Data::Dumper;

my $desc_xtreemfs = N("\nXtreemFS Configuration\n\nXtreemFS is the distributed file system of XtreemOS. It comprises three server modules:\n- Metadata and Replica Catalog (MRC)\n- Object Storage Device (OSD)\n- Directory Service (DIR)\n");
my $desc_xtreemfs_mrc = N("\nXtreemFS Configuration\n\nXtreemFS is the distributed file system of XtreemOS.\nThis is the configuration for the Metadata and Replica Catalog (MRC)\n");
my $desc_xtreemfs_dir = N("\nXtreemFS Configuration\n\nXtreemFS is the distributed file system of XtreemOS.\nThis is the configuration for the Directory Service (DIR)\n");
my $desc_xtreemfs_osd = N("\nXtreemFS Configuration\n\nXtreemFS is the distributed file system of XtreemOS.\nThis is the configuration for the Object Storage Device (OSD)\n");

my $desc_rss =  N("\nRSS Configuration\n\nThe RSS (Resource selection service) is a Java service that provides an overlay network (exploiting \
the Cyclon communication layer) to efficiently locate computing resources based on their static attributes.\n");

my $desc_srds = N("\nSRDS Configuration\n\nService/Resource Discovery Service");

my $desc_xosd = N("\nXOSd Configuration\n");

my $desc_xvoms = N("\nMRC Configuration\n\nMetadata and Replica Catalog XtreemFS's modules\n");

sub basic_explanations {
   my $text = gtknew('TextView');
   use Gtk2::Pango;
   my %common_opts = ('left-margin' => '10', 'right-margin' => '10');
    gtktext_insert($text, ugtk2::markup_to_TextView_format(formatAlaTeX(
#-PO: Do not alter the <span ..> and </span> tags.
#-PO: Translate the security levels (Poor, Standard, High, Higher and Paranoid) in the same way, you translated these individuals words.
#-PO: keep the double empty lines between sections, this is formatted a la LaTeX.
                                          N("
						  <span weight=\"bold\">XtreemOS basic configuration tool</span>


'<span weight=\"bold\" foreground=\"royalblue3\">XtreemFS</span>' 
$desc_xtreemfs

'<span weight=\"bold\" foreground=\"royalblue3\">RSS</span>'
$desc_rss

'<span weight=\"bold\" foreground=\"royalblue3\">XVOMS</span>'
$desc_xvoms

'<span weight=\"bold\" foreground=\"royalblue3\">XOSD</span>'
$desc_xosd

'<span weight=\"bold\" foreground=\"royalblue3\">SRDS</span>'
$desc_srds

")), \%common_opts));

    gtknew('ScrolledWindow', h_policy => 'never', child => $text);
}

my $conf;

sub service_started_on_boot {
    my ($service) = @_;
    my $out = run_program::rooted_get_stdout($::prefix, '/sbin/chkconfig', '--list', $service);
    $out =~ /[234]:on/;
}

sub get_config_keys {
    my ($ui) = @_;

    my %keys = (
	srds => ['disk_device', 'ethernet_device', 'is_bootnode', 'bootstrap_address'],
	xvoms => ['mrc.host', 'mrc.port'],
	xosd => ['rootaddress.host', 'networkInterface', 'externalAddress'],
	rss => ['bootstrap_address', 'bootstrap_port'],
	'xtreemfs-osd' =>  ['listen.port', 'dir_service.host', 'dir_service.port', 'object_dir'],
	'xtreemfs-mrc' =>  ['listen.port', 'dir_service.host', 'dir_service.port', 'database.dir'],
	'xtreemfs-dir' =>  ['database.dir', ],
    );
    return @{$keys{$ui}};
}

sub read {
    	my ($ui) = @_;
    	my %main;
	my @config_keys = get_config_keys($ui);
	foreach my $key (@config_keys) {
	    $main{$key} = xtreemos::xosconfig_get($ui, $key);
	}
	print "read($ui):\n", Dumper(\%main);
        \%main;
}

sub done {
        my ($ui, $conf, $network_interfaces) = @_;

	my @config_keys = get_config_keys($ui);

	foreach (@config_keys) {
	    xtreemos::xosconfig_set($ui, $_, $conf->{$_});
	}
}

sub get_service_names {
    my ($service) = @_;
    foreach my $serv (qw/xosd xtreemfs-osd xtreemfs-mrc xtreemfs-dir/) {
	if ($service =~ /$serv/) {
	    return ($serv);
	}
    }
    return ();
}

my $timeout;
sub gtktext_get_log {
    my ($command, $log_w, $log_scroll, $when_command_is_over) = @_;
    my $buffer = $log_w->get_buffer;
    $buffer->delete($buffer->get_start_iter, $buffer->get_end_iter);
    my ($prev_scroll, $want_scroll_down) = (0, 1);
    my $pid = open(my $F, "$command 2>&1 |") or return sub { 1 };
    fcntl($F, c::F_SETFL(), c::O_NONBLOCK()) or die "can't fcntl F_SETFL: $!";
    #Glib::Source->remove($timeout) if $timeout; $timeout = '';
    $timeout = Glib::Timeout->add(100, sub {
        if ($buffer) {
            my $end = $buffer->get_end_iter;
            while (defined (my $s = <$F>)) {
                $buffer->insert_interactive($end, $s, -1);
            }
            my $new_scroll = $log_scroll->child->get_vadjustment->get_value;
            $want_scroll_down &&= $new_scroll >= $prev_scroll;
            $prev_scroll = $new_scroll;
            $log_w->scroll_to_iter($end, 0, 0, 0, 0) if $want_scroll_down;
        }
        if (waitpid($pid, c::WNOHANG()) > 0) {
            #$buffer->insert($buffer->get_end_iter, "\n" . "-" x 90 . "\n" . "*-end-*" x 10, -1) if $buffer;
            $buffer->insert_interactive($buffer->get_end_iter, "\n" . "#" x 90 . "\n" . " This script has terminated, you can close this window" . "\n" . "#" x 90, -1) if $buffer;
            $when_command_is_over->() if $when_command_is_over;
            $pid = $timeout = '';
            0;
        } else {
            1;
        }
    });
    sub {
        if ($pid) {
            $::in->ask_yesorno('', N("The command is still running. Do you want to kill it?")) or return;
            kill 9, $pid+1;
        }
        $buffer = '';
        1;
    };
}

# call the correct function
sub call_ui {
	# call_ui("srds", $conf);
	my ($ui, $conf) = @_;
	return map {
	    my $key = $_;
	    my %opts;
	    $opts{val} = \$conf->{$key};
	    $opts{key} = $key;
	    $opts{label} = $key;
	    my @list_values = xosconfig_values($ui, $key);
	    if (@list_values) {
		$opts{list} = \@list_values;
	    }
	    my $descr = xosconfig_info($ui, $key);
	    if ($descr) {
		$opts{label} = $descr;
	    }
	    $opts{check} = sub {
		my ($val, $txt) = @_;
		! xosconfig_check($ui, $txt, $val);
	    };
	    \%opts;
	} get_config_keys($ui);
}


sub create {
    my ($conf,$ui) = @_;
    my $apply; my $info;
    my @service_names;
    my ($start, $stop, $restart, $boot_enabled, $boot_enabled_button);
    my @network_interfaces;
    my @fields; @fields = map_index {
        my ($e, $i) = ($_, $::i);
        my ($real_w, $w);
        if ($e->{list}) {
            $w = Gtk2::Combo->new;
            $w->set_use_arrows_always(1);
            $w->entry->set_editable(!$e->{not_edit});
            $w->disable_activate;
            $w->set_popdown_strings(@{$e->{list}});
            ($real_w, $w) = ($w, $w->entry);
        } else {
            $real_w = $w = Gtk2::Entry->new;
        }
        $w->set_text(${$e->{val}});
        $w->signal_connect(changed => sub {
            $apply->set_sensitive(1);
            ${$e->{val}} = $w->get_text;
        });

        # "Return" goes to next entry
        $w->signal_connect(key_press_event => sub {
                             my (undef, $event) = @_;
                             if ($event->keyval == $Gtk2::Gdk::Keysyms{Return}) {
                               ($i < $#fields ? $fields[$i + 1]{w} : $apply)->grab_focus;
                               1;
                             } else {
                               0;
                             }
                           });

        $e->{label_w} = Gtk2::Label->new;
        my $set_label_w = sub {
            my $s = $e->{check} && $e->{check}->(${$e->{val}}, $e->{key}, 'check') ? qq(<span foreground="red">$e->{label}</span>) : $e->{label};
            $e->{label_w}->set_markup($s);
        };
        $set_label_w->();
        $w->signal_connect(focus_out_event => sub { $set_label_w->(); 0 });

        put_in_hash($e, { w => $w, real_w => $real_w });
        $e;
    } call_ui($ui, $conf);

    $apply = Gtk2::Button->new(N("Write the conf"));
    $apply->set_sensitive(0);
    $apply->signal_connect(clicked => sub {
        every {
            if (!xtreemos::check_field($::in, $_)) {
                $_->{w}->grab_focus;
                0;
            } else { 1 }
        } @fields or return;

        $apply->set_sensitive(0);
        xtreemos::done($ui, $conf, \@network_interfaces);
    });

    if ($ui =~ /srds/) {
        $info = $desc_srds;
    } elsif ($ui =~ /xvoms/ ) {
        $info = $desc_xvoms;
    } elsif ($ui =~ /rss/ ) {
        $info = $desc_rss;
    } elsif ($ui =~ /xosd/ ) {
        $info = $desc_xosd;
    } elsif ($ui =~ /xtreemfs-osd/ ) {
        $info = $desc_xtreemfs_osd;
    } elsif ($ui =~ /xtreemfs-mrc/ ) {
	$info = $desc_xtreemfs_mrc;
    } elsif ($ui =~ /xtreemfs-dir/ ) {
	$info = $desc_xtreemfs_dir;
    }

    @service_names = get_service_names($ui);

    if (@service_names) {
	$boot_enabled = service_started_on_boot($service_names[0]);
    }
    my $label_service_name =  Gtk2::Label->new(" @service_names ");
    $start = Gtk2::Button->new(N("Start"));
    $stop = Gtk2::Button->new(N("Stop"));
    $restart = Gtk2::Button->new(N("Restart"));
    $boot_enabled_button = Gtk2::Button->new($boot_enabled ? N("do not start at boot") : N("start at boot"));

    $start->signal_connect(clicked => sub {
	    foreach (@service_names) {
		services::start($_);
	    }
	});
    $stop->signal_connect(clicked => sub {
	    foreach (@service_names) {
		print "stop $_\n";
		services::stop($_);
	    }
	});
    $restart->signal_connect(clicked => sub {
	    foreach (@service_names) {
		services::restart($_);
	    }
	});

    $boot_enabled_button->signal_connect(clicked => sub {
	    my ($button) = @_;
	    foreach (@service_names) {
		my $started = service_started_on_boot($_);
		services::set_status($_, !$started, 1);
		$button->set_label($started ? N("start at boot") : N("do not start at boot"));
	    }
	});

    $start->set_sensitive(@service_names > 0);
    $stop->set_sensitive(@service_names > 0);
    $restart->set_sensitive(@service_names > 0);

    gtkpack_(Gtk2::VBox->new,
             1, gtkadd(gtkset_border_width(Gtk2::Frame->new(N("Information")),5),
		     Gtk2::Label->new($info),
             ),
             0, gtkadd(gtkset_border_width(Gtk2::Frame->new(N("Value")),5),
                       create_packtable({}, map { [ $_->{label_w}, $_->{real_w} ] } @fields),
             ),
             0,  gtkadd(gtkset_border_width(Gtk2::Frame->new(N("Configuration")),5),
                        gtkpack__(Gtk2::HBox->new(0,0),
                                  $apply,
                        ),
             ),
	     !(@service_names > 0) ? () : (
		 0,  gtkadd(gtkset_border_width(Gtk2::Frame->new(N("Manage the service")),5),
			    gtkpack__(Gtk2::HBox->new(0,0),
				      $label_service_name,
				      $start,
				      $stop,
				      $restart,
				      $boot_enabled_button,
			    ),
		 ),
	     ),
	);
}

our $xosconfig_set_func;
sub xosconfig_set {
    defined($xosconfig_set_func) && return &$xosconfig_set_func(@_);
    my ($module, $key, $value) = @_;
    run_program::rooted($::prefix, '/usr/sbin/xosconfig', $module, 'set', $key, $value);
    #xtreemos::config::set_config($module, $key, $value);
}

our $xosconfig_check_func;
sub xosconfig_check {
    defined($xosconfig_check_func) && return &$xosconfig_check_func(@_);
    my ($module, $key, $value) = @_;
    my $res = run_program::rooted_get_stdout($::prefix, '/usr/sbin/xosconfig', $module, 'check', $key, $value);
    chomp $res;
    $res eq "ok";
}

our $xosconfig_get_func;
sub xosconfig_get {
    defined($xosconfig_get_func) && return &$xosconfig_get_func(@_);
    my ($module, $key) = @_;
    my $res = run_program::rooted_get_stdout($::prefix, '/usr/sbin/xosconfig', $module, 'get', $key);
    #my $res = xtreemos::config::get_config($module, $key);
    chomp $res;
    $res;
}

our $xosconfig_values_func;
sub xosconfig_values {
    defined($xosconfig_values_func) && return &$xosconfig_values_func(@_);
    my ($module, $key) = @_;
    my $res = run_program::rooted_get_stdout($::prefix, '/usr/sbin/xosconfig', $module, 'values', $key);
    #my $res = xtreemos::config::get_config($module, $key);
    split(/\n/, $res);
}

our $xosconfig_info_func;
sub xosconfig_info {
    defined($xosconfig_info_func) && return &$xosconfig_info_func(@_);
    my ($module, $key) = @_;
    my $res = run_program::rooted_get_stdout($::prefix, '/usr/sbin/xosconfig', $module, 'info', $key);
    #my $res = xtreemos::config::get_config($module, $key);
    chomp $res;
    $res;
}

my $force_size;
sub my_gtk::show {
    my ($o) = @_;
    $o->{rwindow}->set_usize($::windowwidth * 0.9, $::windowheight * 0.9) if $force_size;
    $force_size = 0;
    $o->{window}->show;
    $o->{rwindow}->show;
}

sub check_field {
    my ($in, $field) = @_;
    warn "checking $field->{label}\n";
    $field->{check} or return 1;
    my $err = $field->{check}->(${$field->{val}}, $field->{key}, warn => $in);
    if (!$::isInstall) { 
        my $in = 'interactive'->vnew('su');
    }
    $in->ask_warn('', $err) if $err && $err ne 'already_displayed';
    !$err;
}

sub main_xtreemfs_osd {
    my ($o) = @_;
    my $conf = xtreemos::read('xtreemfs-osd');
    my @fields = xtreemos::xtreemfs_osd::fields($conf);
    $force_size = 1;
    $o->ask_from('', $desc_xtreemfs_osd,
		  [ @fields ], complete => sub {
		      my $i = eval { find_index { !xtreemos::check_field($o, $_) } @fields };
		      $@ ? 0 : (1, $i);
		  }) or return;
    xtreemos::done('xtreemfs-osd', $conf);
}

sub main_xtreemfs_mrc {
    my ($o) = @_;
    my $conf = xtreemos::read('xtreemfs-mrc');
    my @fields = xtreemos::xtreemfs_mrc::fields($conf);
    $force_size = 1;
    $o->ask_from('', $desc_xtreemfs_mrc,
		  [ @fields ], complete => sub {
		      my $i = eval { find_index { !xtreemos::check_field($o, $_) } @fields };
		      $@ ? 0 : (1, $i);
		  }) or return;
    xtreemos::done('xtreemfs-mrc', $conf);
}

sub main_xtreemfs_dir {
    my ($o) = @_;
    my $conf = xtreemos::read('xtreemfs-dir');
    my @fields = xtreemos::xtreemfs_dir::fields($conf);
    $force_size = 1;
    $o->ask_from('', $desc_xtreemfs_dir,
		  [ @fields ], complete => sub {
		      my $i = eval { find_index { !xtreemos::check_field($o, $_) } @fields };
		      $@ ? 0 : (1, $i);
		  }) or return;
    xtreemos::done('xtreemfs-dir', $conf);
}

sub main_xosd {
    my ($o) = @_;
    my @network_interfaces = detect_devices::get_lan_interfaces();
    my $conf = xtreemos::read('xosd');
    my @fields = xtreemos::xosd::fields($conf, \@network_interfaces);
    $force_size = 1;
    $o->ask_from('', $desc_xosd,
		  [ @fields ], complete => sub {
		      my $i = eval { find_index { !xtreemos::check_field($o, $_) } @fields };
		      $@ ? 0 : (1, $i);
		  }) or return;
    xtreemos::done('xosd', $conf, \@network_interfaces);
}

sub main_rss {
    my ($o) = @_;
    my $conf = xtreemos::read('rss');
    my @fields = xtreemos::rss::fields($conf);
    $force_size = 1;
    $o->ask_from('', $desc_rss,
		  [ @fields ], complete => sub {
		      my $i = eval { find_index { !xtreemos::check_field($o, $_) } @fields };
		      $@ ? 0 : (1, $i);
		  }) or return;

    xtreemos::done('rss', $conf);
}

sub main_xvoms {
    my ($o) = @_;
    my $conf = xtreemos::read('xvoms');
    my @fields = xtreemos::xvoms::fields($conf);
    $force_size = 1;
    $o->ask_from('', $desc_xvoms,
		  [ @fields ], complete => sub {
		      my $i = eval { find_index { !xtreemos::check_field($o, $_) } @fields };
		      $@ ? 0 : (1, $i);
		  }) or return;

    xtreemos::done('xvoms', $conf);
}

sub main_srds {
    my ($o) = @_;
    my $conf = xtreemos::read('srds');
    my @network_interfaces = detect_devices::get_lan_interfaces();
    my @fields = xtreemos::srds::fields($conf, \@network_interfaces);
    $force_size = 1;
    $o->ask_from('', $desc_srds,
		  [ @fields ], complete => sub {
		      my $i = eval { find_index { !xtreemos::check_field($o, $_) } @fields };
		      $@ ? 0 : (1, $i);
		  }) or return;

    xtreemos::done('srds', $conf);
}

1;

